==> cloud-5.1.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/entity/openstack/image.ts <==
import EntityInfoTemplate from 'model/EntityInfoTemplate';

// Template for displaying detailed information about entities in OpenStack.
const OPENSTACK_IMAGE_TEMPLATE: EntityInfoTemplate = {
  cloudServiceProvider: 'openstack',
  entityName: 'image',
  entityRecords: [
    {
      panelName: 'Image',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Name', name: 'name', type: 'default' },
        { labelName: 'Image ID', name: 'image_id', type: 'default' },
        { labelName: 'Owner', name: 'account_id', type: 'default' },
        { labelName: 'Status', name: 'status', type: 'default' },
        { labelName: 'Created', name: 'created', type: 'datetime' },
      ]
    },
    {
      panelName: 'Launch Permission',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Visibility', name: 'visibility', type: 'boolean', value: ['On', 'Off'] },
      ]
    },
    {
      panelName: 'Type',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Image type', name: 'image_type', type: 'default' },
      ]
    },
    {
      panelName: 'Device',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Root device type', name: 'root_device_type', type: 'default' },
      ]
    },
    {
      panelName: 'Others',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Cloud service provider ID', name: 'cloud_context', type: 'default' },
      ]
    },
  ]
};

export default OPENSTACK_IMAGE_TEMPLATE;

==> cloud-6.0.0-rc2.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/entity/openstack/image.ts <==
import EntityInfoTemplate from 'model/EntityInfoTemplate';

// Template for displaying detailed information about entities in OpenStack.
const OPENSTACK_IMAGE_TEMPLATE: EntityInfoTemplate = {
  cloudServiceProvider: 'openstack',
  entityName: 'image',
  entityRecords: [
    {
      panelName: 'Image',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Name', name: 'name', type: 'default', id: 'field--name-name', class: 'field--name-name' },
        { labelName: 'Image ID', name: 'image_id', type: 'default' },
        { labelName: 'Owner', name: 'account_id', type: 'default' },
        { labelName: 'Status', name: 'status', type: 'default' },
        { labelName: 'Created', name: 'created', type: 'datetime' },
      ]
    },
    {
      panelName: 'Launch Permission',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Visibility', name: 'visibility', type: 'boolean', value: ['On', 'Off'] },
      ]
    },
    {
      panelName: 'Type',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Image type', name: 'image_type', type: 'default' },
      ]
    },
    {
      panelName: 'Device',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Root device type', name: 'root_device_type', type: 'default' },
      ]
    },
    {
      panelName: 'Others',
      tableRecordList: [],
      keyValueRecords: [
        { labelName: 'Cloud service provider ID', name: 'cloud_context', type: 'default' },
      ]
    },
  ]
};

export default OPENSTACK_IMAGE_TEMPLATE;
